Crate ya_sb_router

Gsb Router

use ya_sb_router::{InstanceConfig, RouterConfig};

#[actix_rt::main]
async fn main() {
    let mut config = RouterConfig::from_env();
    config.gc_interval_secs(60);
    InstanceConfig::new(config).run_url(None).await;
}

Structs

InstanceConfig
Router config with instance identification info.
RouterConfig
Message router configuration.

Functions

bind_gsb_router
Starts in background new server instance on given gsb address.
bind_tcp_router
Starts in background new server instance on given tcp address.