Gsb Router
use ya_sb_router::{InstanceConfig, RouterConfig};
#[actix_rt::main]
async fn main() {
let mut config = RouterConfig::from_env();
config.gc_interval_secs(60);
InstanceConfig::new(config).run_url(None).await;
}
Structs
- Instance
Config - Router config with instance identification info.
- Router
Config - Message router configuration.
Functions
- bind_
gsb_ router - Starts in background new server instance on given gsb address.
- bind_
tcp_ router - Starts in background new server instance on given tcp address.